---
name: "\U0001F41E Bug report"
about: Create a report to help us improve
title: ''
labels: kind/bug, status/triage
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Link to project**
If possible, provide a public renkulab link to the project with the bug.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots and/or execution output**
If applicable, add screenshots and/or execution output to help explain your problem.

**Run environment (please complete the following information):**
 - local terminal OR renkulab browser?
 - specify RStudio / Jupyterlab / Other
 - renku-python version
 - browser [e.g. chrome, safari]

**Additional context**
Add any other context about the problem here.
